@@ -1,6 +1,6 @@
 /*
     DABlin - capital DAB experience
-    Copyright (C) 2015-2020 Stefan Pöschel
+    Copyright (C) 2015-2024 Stefan Pöschel
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -43,7 +43,8 @@ static void usage(const char* exe) {
 					"  -R <subchid>  ID of the sub-channel (DAB+) to be played\n"
 					"  -g <gain>     USB stick gain to pass to DAB live source (auto gain is default)\n"
 					"  -G            Use default gain for DAB live source (instead of auto gain)\n"
-					"  -p            Output PCM to stdout instead of using SDL\n"
+					"  -p            Output raw PCM to stdout instead of using SDL\n"
+					"  -w            Output RIFF WAVE with PCM to stdout instead of using SDL (useful only on Little Endian)\n"
 					"  -u            Output untouched audio stream to stdout instead of using SDL\n"
 					"  -I            Don't catch up on stream after interruption\n"
 					"  -F            Disable dynamic FIC messages (dynamic PTY, announcements)\n"
@@ -74,7 +75,7 @@ int main(int argc, char **argv) {
 
 	// option args
 	int c;
-	while((c = getopt(argc, argv, "hf:c:l:d:D:g:Gs:x:1puIFr:R:")) != -1) {
+	while((c = getopt(argc, argv, "hf:c:l:d:D:g:Gs:x:1pwuIFr:R:")) != -1) {
 		switch(c) {
 		case 'h':
 			usage(argv[0]);
@@ -125,6 +126,9 @@ int main(int argc, char **argv) {
 		case 'p':
 			options.pcm_output = true;
 			break;
+		case 'w':
+			options.wav_output = true;
+			break;
 		case 'u':
 			options.untouched_output = true;
 			break;
@@ -190,7 +194,7 @@ int main(int argc, char **argv) {
 	}
 #endif
 
-	if(options.pcm_output && options.untouched_output) {
+	if(options.pcm_output + options.wav_output + options.untouched_output > 1) {
 		fprintf(stderr, "No more than one output option can be specified!\n");
 		usage(argv[0]);
 	}
@@ -225,10 +229,20 @@ DABlinText::DABlinText(DABlinTextOptions options) {
 	// set XTerm window title to version string
 	fprintf(stderr, "\x1B]0;" "DABlin v" DABLIN_VERSION "\a");
 
+	AudioOutputType audio_output_type = AudioOutputType::SDL;
+#ifndef DABLIN_DISABLE_SDL
+	if(options.pcm_output)
+#endif
+		audio_output_type = AudioOutputType::PCM;
+	if(options.wav_output)
+		audio_output_type = AudioOutputType::WAV;
+	if(options.untouched_output)
+		audio_output_type = AudioOutputType::Untouched;
+
 	if(options.source_format == EnsembleSource::FORMAT_ETI)
-		ensemble_player = new ETIPlayer(options.pcm_output, options.untouched_output, options.disable_int_catch_up, this);
+		ensemble_player = new ETIPlayer(audio_output_type, options.disable_int_catch_up, this);
 	else
-		ensemble_player = new EDIPlayer(options.pcm_output, options.untouched_output, options.disable_int_catch_up, this);
+		ensemble_player = new EDIPlayer(audio_output_type, options.disable_int_catch_up, this);
 
 	// set initial sub-channel, if desired
 	if(options.initial_subchid_dab != AUDIO_SERVICE::subchid_none) {
