@@ -1,6 +1,6 @@
 /*
     DABlin - capital DAB experience
-    Copyright (C) 2015-2018 Stefan Pöschel
+    Copyright (C) 2015-2024 Stefan Pöschel
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdexcept>
-#include <sstream>
 #include <string>
 
 #if !(defined(DABLIN_AAC_FAAD2) ^ defined(DABLIN_AAC_FDKAAC))
@@ -65,6 +64,9 @@ struct SuperframeFormat {
 	bool IsSBR() {
 		return sbr_flag;
 	}
+	size_t GetAULengthMs() {
+		return dac_rate ? (sbr_flag ? 40 : 20) : (sbr_flag ? 60 : 30);	// 24/48/16/32 kHz
+	}
 };
 
 
@@ -78,7 +80,7 @@ public:
 	RSDecoder();
 	~RSDecoder();
 
-	void DecodeSuperframe(uint8_t *sf, size_t sf_len);
+	void DecodeSuperframe(uint8_t *sf, size_t sf_len, int& total_corr_count, bool& uncorr_errors);
 };
 
 
@@ -157,7 +159,6 @@ private:
 	void ProcessFormat();
 	void ProcessUntouchedStream(const uint8_t *data, size_t len);
 	void CheckForPAD(const uint8_t *data, size_t len);
-	void ResetPAD();
 public:
 	SuperframeFilter(SubchannelSinkObserver* observer, bool decode_audio);
 	~SuperframeFilter();
