@@ -1,6 +1,6 @@
 /*
     DABlin - capital DAB experience
-    Copyright (C) 2015-2019 Stefan Pöschel
+    Copyright (C) 2015-2024 Stefan Pöschel
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,9 +34,14 @@
 #include "dab_decoder.h"
 #include "dabplus_decoder.h"
 #include "pcm_output.h"
+#include "wav_output.h"
 #include "tools.h"
 
 
+// --- AudioOutputType -----------------------------------------------------------------
+enum class AudioOutputType { SDL, PCM, WAV, Untouched };
+
+
 // --- EnsemblePlayerObserver -----------------------------------------------------------------
 class EnsemblePlayerObserver {
 public:
@@ -51,7 +56,7 @@ public:
 // --- EnsemblePlayer -----------------------------------------------------------------
 class EnsemblePlayer : SubchannelSinkObserver, UntouchedStreamConsumer {
 protected:
-	bool untouched_output;
+	AudioOutputType audio_output_type;
 	bool disable_int_catch_up;
 	EnsemblePlayerObserver *observer;
 
@@ -66,7 +71,7 @@ protected:
 	virtual void DecodeFrame(const uint8_t *ensemble_frame) = 0;
 
 	void FormatChange(const AUDIO_SERVICE_FORMAT& format);
-	void StartAudio(int samplerate, int channels, bool float32) {if(out) out->StartAudio(samplerate, channels, float32);}
+	void StartAudio(int samplerate, int channels) {if(out) out->StartAudio(samplerate, channels);}
 	void PutAudio(const uint8_t *data, size_t len) {if(out) out->PutAudio(data, len);}
 
 	void ProcessFIC(const uint8_t *data, size_t len);
@@ -77,7 +82,7 @@ protected:
 	void AudioWarning(const std::string& hint);
 	void FECInfo(int total_corr_count, bool uncorr_errors);
 public:
-	EnsemblePlayer(bool pcm_output, bool untouched_output, bool disable_int_catch_up, EnsemblePlayerObserver *observer);
+	EnsemblePlayer(AudioOutputType audio_output_type, bool disable_int_catch_up, EnsemblePlayerObserver *observer);
 	~EnsemblePlayer();
 
 	void ProcessFrame(const uint8_t *data);
