@@ -1,6 +1,6 @@
 /*
     DABlin - capital DAB experience
-    Copyright (C) 2015-2019 Stefan Pöschel
+    Copyright (C) 2015-2020 Stefan Pöschel
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,11 +45,14 @@ void DABLiveETISource::PrintSource() {
 }
 
 DABLiveETISource::~DABLiveETISource() {
-	// TODO: replace bad style temporary solution (here possible, because dab2eti allows only one concurrent session)
-	std::string cmd_killall = "killall " + binary_name;
-	int result = system(cmd_killall.c_str());
-	if(result != 0)
-		fprintf(stderr, "DABLiveETISource: error killing %s\n", source_name.c_str());
+	// kill source, if not yet terminated
+	if(!feof(input_file)) {
+		// TODO: replace bad style temporary solution (here possible, because dab2eti allows only one concurrent session)
+		std::string cmd_killall = "killall " + binary_name;
+		int result = system(cmd_killall.c_str());
+		if(result != 0)
+			fprintf(stderr, "DABLiveETISource: error killing %s\n", source_name.c_str());
+	}
 
 	pclose(input_file);
 	input_file = nullptr;
@@ -59,8 +62,14 @@ DABLiveETISource::~DABLiveETISource() {
 // --- DAB2ETIETISource -----------------------------------------------------------------
 std::string DAB2ETIETISource::GetParams() {
 	std::string result = std::to_string(channel.freq * 1000);
-	if(!channel.HasAutoGain())
+	switch(channel.gain) {
+	case DAB_LIVE_SOURCE_CHANNEL::auto_gain:
+	case DAB_LIVE_SOURCE_CHANNEL::default_gain:
+		// here: default = auto
+		break;
+	default:
 		result += " " + std::to_string(channel.gain);
+	}
 	return result;
 }
 
@@ -68,9 +77,15 @@ std::string DAB2ETIETISource::GetParams() {
 // --- EtiCmdlineETISource -----------------------------------------------------------------
 std::string EtiCmdlineETISource::GetParams() {
 	std::string cmdline = "-C " + channel.block + " -S -B " + (channel.freq < 1000000 ? "BAND_III" : "L_BAND");
-	if(channel.HasAutoGain())
+	switch(channel.gain) {
+	case DAB_LIVE_SOURCE_CHANNEL::auto_gain:
 		cmdline += " -Q";
-	else
+		break;
+	case DAB_LIVE_SOURCE_CHANNEL::default_gain:
+		// no parameter
+		break;
+	default:
 		cmdline += " -G " + std::to_string(channel.gain);
+	}
 	return cmdline;
 }
