@@ -1,6 +1,6 @@
 /*
     DABlin - capital DAB experience
-    Copyright (C) 2015-2016 Stefan Pöschel
+    Copyright (C) 2015-2024 Stefan Pöschel
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,25 +23,23 @@
 PCMOutput::PCMOutput() : AudioOutput() {
 	samplerate = 0;
 	channels = 0;
-	float32 = false;
 
 	audio_mute = false;
 }
 
-void PCMOutput::StartAudio(int samplerate, int channels, bool float32) {
+void PCMOutput::StartAudio(int samplerate, int channels) {
 	// if no change, return
-	if(this->samplerate == samplerate && this->channels == channels && this->float32 == float32)
+	if(this->samplerate == samplerate && this->channels == channels)
 		return;
 	this->samplerate = samplerate;
 	this->channels = channels;
-	this->float32 = float32;
 
-	fprintf(stderr, "PCMOutput: format set; samplerate: %d, channels: %d, output: %s\n",
-			samplerate,
-			channels,
-			float32 ? "32bit float" : "16bit integer");
+	ChangeFormat(samplerate, channels);
 }
 
+void PCMOutput::ChangeFormat(int samplerate, int channels) {
+	fprintf(stderr, "PCMOutput: format set; samplerate: %d, channels: %d\n", samplerate, channels);
+}
 
 void PCMOutput::PutAudio(const uint8_t *data, size_t len) {
 	if(!audio_mute)
