@@ -1,6 +1,6 @@
 /*
     DABlin - capital DAB experience
-    Copyright (C) 2015-2019 Stefan Pöschel
+    Copyright (C) 2015-2024 Stefan Pöschel
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,14 +31,15 @@ class PCMOutput : public AudioOutput {
 private:
 	int samplerate;
 	int channels;
-	bool float32;
 
 	std::atomic<bool> audio_mute;
+protected:
+	virtual void ChangeFormat(int samplerate, int channels);
 public:
 	PCMOutput();
 	~PCMOutput() {}
 
-	void StartAudio(int samplerate, int channels, bool float32);
+	void StartAudio(int samplerate, int channels);
 	void StopAudio() {}
 	void PutAudio(const uint8_t *data, size_t len);
 	void SetAudioMute(bool audio_mute) {this->audio_mute = audio_mute;}
